Index: /BAORadio/AmasNancay/calibmaker.sh
===================================================================
--- /BAORadio/AmasNancay/calibmaker.sh	(revision 509)
+++ /BAORadio/AmasNancay/calibmaker.sh	(revision 510)
@@ -100,5 +100,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 #get the daq current irod status
Index: /BAORadio/AmasNancay/gainmaker.sh
===================================================================
--- /BAORadio/AmasNancay/gainmaker.sh	(revision 509)
+++ /BAORadio/AmasNancay/gainmaker.sh	(revision 510)
@@ -98,5 +98,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 
Index: /BAORadio/AmasNancay/getscafiles.sh
===================================================================
--- /BAORadio/AmasNancay/getscafiles.sh	(revision 509)
+++ /BAORadio/AmasNancay/getscafiles.sh	(revision 510)
@@ -63,5 +63,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 #look if the run exists
Index: /BAORadio/AmasNancay/getsignalfiles.sh
===================================================================
--- /BAORadio/AmasNancay/getsignalfiles.sh	(revision 509)
+++ /BAORadio/AmasNancay/getsignalfiles.sh	(revision 510)
@@ -62,5 +62,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 
Index: /BAORadio/AmasNancay/hdrfitsextractor.sh
===================================================================
--- /BAORadio/AmasNancay/hdrfitsextractor.sh	(revision 509)
+++ /BAORadio/AmasNancay/hdrfitsextractor.sh	(revision 510)
@@ -45,5 +45,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 
@@ -68,7 +68,7 @@
 
 
-workDir="headers"
-$MKDIR -p ./${workDir}
-cd ./${workDir}
+workArea="headers"
+$MKDIR -p ./${workArea}
+cd ./${workArea}
 
 
Index: /BAORadio/AmasNancay/scaextractor.sh
===================================================================
--- /BAORadio/AmasNancay/scaextractor.sh	(revision 509)
+++ /BAORadio/AmasNancay/scaextractor.sh	(revision 510)
@@ -52,5 +52,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 
Index: /BAORadio/AmasNancay/select.sh
===================================================================
--- /BAORadio/AmasNancay/select.sh	(revision 509)
+++ /BAORadio/AmasNancay/select.sh	(revision 510)
@@ -39,5 +39,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 
Index: /BAORadio/AmasNancay/statuscalib.sh
===================================================================
--- /BAORadio/AmasNancay/statuscalib.sh	(revision 509)
+++ /BAORadio/AmasNancay/statuscalib.sh	(revision 510)
@@ -104,4 +104,6 @@
     dateField=`basename ${j}`
     sourceDate="${sourceName}-${dateField}"
+#look if final calibration files exist
+    calibOk=`ils ${j} | $GREP -i "calib_" | $WC -l`
     onDirExist=`ils ${j} | $GREP -i "On" | $WC -l`
     if [ ${onDirExist} != 0 ]; then
@@ -118,5 +120,5 @@
 	     nFiles=`ils ${j}/On/${c} | $GREP -i "medfiltmtx" | $WC -l`
 	     if [ ${nFiles} != 0 ]; then
-		 $ECHO "${sourceDate}/On/${c}: ${nFiles} files"
+		 $ECHO "${sourceDate}/On/${c}: ${nFiles} spectra (${calibOk} calib)"
 	     else
 		 $ECHO "${sourceDate}/On/${c}: Calibration failed"
Index: /BAORadio/AmasNancay/submit2bqs-calibmaker.sh
===================================================================
--- /BAORadio/AmasNancay/submit2bqs-calibmaker.sh	(revision 509)
+++ /BAORadio/AmasNancay/submit2bqs-calibmaker.sh	(revision 510)
@@ -41,4 +41,4 @@
 
 qsub -l u_sps_baoradio,u_irods,T=120000,M=1000MB,scratch=1000MB,platform=LINUX -eo -o $jobLogName -N $jobBatchName -mb -me -mu campagne@lal.in2p3.fr <<EOF
-/afs/in2p3.fr/home/c/campagne/private/work/calibmaker.sh  -src ${sourceRadio} ${freqBAOCalib} ${bwBAOCalib} ${simulationMode}
+/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay/calibmaker.sh  -src ${sourceRadio} ${freqBAOCalib} ${bwBAOCalib} ${simulationMode}
 EOF
Index: /BAORadio/AmasNancay/submit2bqs-gainmaker.sh
===================================================================
--- /BAORadio/AmasNancay/submit2bqs-gainmaker.sh	(revision 509)
+++ /BAORadio/AmasNancay/submit2bqs-gainmaker.sh	(revision 510)
@@ -23,4 +23,4 @@
 
 qsub -l u_sps_baoradio,u_irods,T=120000,M=1000MB,scratch=500MB,platform=LINUX -eo -o $jobLogName -N $jobBatchName -mb -me -mu campagne@lal.in2p3.fr <<EOF
-/afs/in2p3.fr/home/c/campagne/private/work/gainmaker.sh  -src ${sourceRadio} ${simulationMode}
+/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay/gainmaker.sh  -src ${sourceRadio} ${simulationMode}
 EOF
Index: /BAORadio/AmasNancay/submit2bqs-hdrfitsextractor.sh
===================================================================
--- /BAORadio/AmasNancay/submit2bqs-hdrfitsextractor.sh	(revision 509)
+++ /BAORadio/AmasNancay/submit2bqs-hdrfitsextractor.sh	(revision 510)
@@ -20,4 +20,4 @@
 
 qsub -l u_sps_baoradio,u_irods,T=100000,M=256MB,scratch=700MB,platform=LINUX -eo -o $jobLogName -N $jobBatchName -mb -me -mu campagne@lal.in2p3.fr <<EOF
-/afs/in2p3.fr/home/c/campagne/private/work/hdrfitsextractor.sh  $sourceRadio
+/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay/hdrfitsextractor.sh  $sourceRadio
 EOF
Index: /BAORadio/AmasNancay/submit2bqs-scaextractor.sh
===================================================================
--- /BAORadio/AmasNancay/submit2bqs-scaextractor.sh	(revision 509)
+++ /BAORadio/AmasNancay/submit2bqs-scaextractor.sh	(revision 510)
@@ -41,5 +41,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 #the daq current irod status
@@ -63,4 +63,4 @@
 
 qsub -l u_sps_baoradio,u_irods,T=100000,M=256MB,scratch=700MB,platform=LINUX -eo -o $jobLogName -N $jobBatchName -mb -me -mu campagne@lal.in2p3.fr <<EOF
-/afs/in2p3.fr/home/c/campagne/private/work/scaextractor.sh  $sourceRadio
+/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay/scaextractor.sh  $sourceRadio
 EOF

Index: /BAORadio/AmasNancay/proc_script.sh
===================================================================
--- /BAORadio/AmasNancay/proc_script.sh	(revision 509)
+++ /BAORadio/AmasNancay/proc_script.sh	(revision 510)
@@ -75,5 +75,5 @@
 
 #Path of the utility scripts
-scriptpath="/afs/in2p3.fr/home/c/campagne/private/work"
+scriptpath="/afs/in2p3.fr/home/c/campagne/private/work/AmasNancay"
 
 
@@ -465,5 +465,5 @@
     iput -v -K -r \${curDir}/${dirName} /baoradio/data/AmasNancay/\${localpath}
 #
 #clean the signal files which can at the end of the day fill completly the scratch directory of the batch worker
     $RM -f \${iojobpath}/\${localpath}/Fiber1/signal*.fits
     $RM -f \${iojobpath}/\${localpath}/Fiber2/signal*.fits
@@ -465,5 +465,5 @@
     iput -v -K -r \${curDir}/${dirName} /baoradio/data/AmasNancay/\${localpath}
 #
-#clean the signal files which can at the end of the day fill completly the scratch directory of the batch worker
+#clean the signal files which can at the end of the day fill completly the scratch directory of the batch work/AmasNancayer
     $RM -f \${iojobpath}/\${localpath}/Fiber1/signal*.fits
     $RM -f \${iojobpath}/\${localpath}/Fiber2/signal*.fits